Add RaiseSlit command.
    Tomas Janousek <tomi@nomi.cz>

Index: WorkspaceCmd.hh
===================================================================
--- WorkspaceCmd.hh	(revision 4694)
+++ WorkspaceCmd.hh	(working copy)
@@ -104,6 +104,11 @@
     void execute();
 };
 
+class RaiseSlitCmd: public FbTk::Command {
+public:
+    void execute();
+};
+
 class MinimizeLayerCmd: public FbTk::Command {
 public:
     void execute();
Index: WorkspaceCmd.cc
===================================================================
--- WorkspaceCmd.cc	(revision 4694)
+++ WorkspaceCmd.cc	(working copy)
@@ -30,6 +30,9 @@
 #include "fluxbox.hh"
 #include "WinClient.hh"
 #include "FocusControl.hh"
+#ifdef SLIT
+#include "Slit.hh"
+#endif // SLIT
 
 #include "FbTk/KeyUtil.hh"
 
@@ -255,6 +265,25 @@
                   std::mem_fun(&FluxboxWindow::iconify));
 }
 
+void RaiseSlitCmd::execute() {
+#ifdef SLIT
+    BScreen *screen = Fluxbox::instance()->mouseScreen();
+    if (screen == 0)
+        return;
+
+    static bool raise = true;
+
+    if (screen->slit()) {
+	if (raise)
+	    screen->slit()->raise();
+	else
+	    screen->slit()->lower();
+
+	raise = !raise;
+    }
+#endif // SLIT
+}
+
 void MinimizeLayerCmd::execute() {
     FluxboxWindow *win = FocusControl::focusedFbWindow();
     if (!win)
Index: FbCommandFactory.cc
===================================================================
--- FbCommandFactory.cc	(revision 4694)
+++ FbCommandFactory.cc	(working copy)
@@ -109,6 +109,7 @@
         "quit",
         "raise",
         "raiselayer",
+        "raiseslit",
         "reconfig",
         "reconfigure",
         "reloadstyle",
@@ -410,6 +411,8 @@
         return new ArrangeWindowsCmd();
     else if (command == "showdesktop")
         return new ShowDesktopCmd();
+    else if (command == "raiseslit")
+        return new RaiseSlitCmd();
     else if (command == "rootmenu")
         return new ShowRootMenuCmd();
     else if (command == "workspacemenu")
Index: Slit.hh
===================================================================
--- Slit.hh	(revision 4694)
+++ Slit.hh	(working copy)
@@ -104,6 +104,9 @@
     void moveToLayer(int layernum);
     void toggleHidden();
 
+    void raise() { frame.window.raise(); }
+    void lower() { frame.window.lower(); }
+
     BScreen &screen() { return m_screen; }
     const BScreen &screen() const { return m_screen; }
     SlitTheme &theme() { return *m_slit_theme.get(); }
